@@ -21,6 +21,8 @@
 
 .realgarchfit = function(spec, data, out.sample = 0, solver = "solnp", solver.control = list(), 
 		fit.control = list(stationarity = 1, fixed.se = 0, scale = 0, rec.init = 'all'), 
+		numderiv.control = list(grad.eps=1e-4, grad.d=0.0001, grad.zero.tol=sqrt(.Machine$double.eps/7e-7),
+				hess.eps=1e-4, hess.d=0.1, hess.zero.tol=sqrt(.Machine$double.eps/7e-7), r=4, v=2),
 		realizedVol = NULL)
 {
 	tic = Sys.time()
@@ -226,7 +228,7 @@
 		arglist$data = data
 		fit = .makefitmodel(garchmodel = "realGARCH", f = .realgarchLLH, T = T, m = m, 
 				timer = timer, convergence = convergence, message = sol$message, 
-				hess, arglist = arglist)
+				hess, arglist = arglist, numderiv.control = numderiv.control)
 		model$modeldata$realizedVol = realizedVol
 		model$modelinc[7] = modelinc[7]
 		model$modeldata$data = origdata
@@ -1141,6 +1143,7 @@ epsfn = function(A, e, b, n.ahead, ed)
 						PACKAGE = "rugarch"), silent = TRUE)
 		if(inherits(ans1, "try-error")) stop("\nugarchpath-->error: error in calling C function....\n")
 		sigmaSim[,i] = ans1$h[(n.start + m + 1):(n+m)]^(1/2)
+		realizedSim[,i] = ans1$r[(n.start + m + 1):(n+m)]
 		residSim[,i] = ans1$res[(n.start + m + 1):(n+m)]
 		if(modelinc[6]>0){
 			mxreg = matrix( ipars[idx["mxreg",1]:idx["mxreg",2], 1], ncol = modelinc[6] )
